==> dde-calendar_5.8.29.orig.tar.xz: dde-calendar-5.8.29/translations/dde-calendar-service_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>JobRemindManager</name>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <source>One day before start</source>
        <translation>O zi înainte de a începe</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="94"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="109"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>Închidere</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="98"/>
        <source>Remind me tomorrow</source>
        <translation>Reaminteşte mâine</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="105"/>
        <source>Remind me later</source>
        <translation>Reaminteşte mai târziu</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="116"/>
        <source>Schedule Reminder</source>
        <translation>Programare Reminder</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="236"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="245"/>
        <source>%1 to %2</source>
        <translation>%1 la %2</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="317"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="328"/>
        <source>Today</source>
        <translation>Azi</translation>
    </message>
    <message>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="320"/>
        <location filename="../calendar-service/src/jobremindmanager.cpp" line="331"/>
        <source>Tomorrow</source>
        <translation>Mâine</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_ro.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ro">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Serviciu</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Viaţă</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Altul</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Închidere</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>O zi înainte de a începe</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Reaminteşte mâine</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Reaminteşte mai târziu</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1 hour later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>4 hours later</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Mâine</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Programare Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 la %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Astăzi</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">O zi înainte de a începe</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Închidere</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Reaminteşte mâine</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Reaminteşte mai târziu</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Programare Reminder</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 la %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Azi</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Mâine</translation>
    </message>
</context>
</TS>
